<?php
/**
 * The Computer Repair Theme Customizer
 *
 * @package The Computer Repair
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function the_computer_repair_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'the_computer_repair_custom_controls' );

function the_computer_repair_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; $wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'the_computer_repair_customize_partial_blogname', 
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'the_computer_repair_customize_partial_blogdescription', 
	));

	$TheComputerRepairParentPanel = new The_Computer_Repair_WP_Customize_Panel( $wp_customize, 'the_computer_repair_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => 'VW Settings',
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'the_computer_repair_left_right', array(
    	'title'      => __( 'General Settings', 'the-computer-repair' ),
		'panel' => 'the_computer_repair_panel_id'
	) );

	$wp_customize->add_setting('the_computer_repair_width_option',array(
        'default' => __('Full Width','the-computer-repair'),
        'sanitize_callback' => 'the_computer_repair_sanitize_choices'
	));
	$wp_customize->add_control(new The_Computer_Repair_Image_Radio_Control($wp_customize, 'the_computer_repair_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','the-computer-repair'),
        'description' => __('Here you can change the width layout of Website.','the-computer-repair'),
        'section' => 'the_computer_repair_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('the_computer_repair_theme_options',array(
        'default' => __('Right Sidebar','the-computer-repair'),
        'sanitize_callback' => 'the_computer_repair_sanitize_choices'	        
	) );
	$wp_customize->add_control('the_computer_repair_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','the-computer-repair'),
        'description' => __('Here you can change the sidebar layout for posts. ','the-computer-repair'),
        'section' => 'the_computer_repair_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','the-computer-repair'),
            'Right Sidebar' => __('Right Sidebar','the-computer-repair'),
            'One Column' => __('One Column','the-computer-repair'),
            'Three Columns' => __('Three Columns','the-computer-repair'),
            'Four Columns' => __('Four Columns','the-computer-repair'),
            'Grid Layout' => __('Grid Layout','the-computer-repair')
        ),
	));

	$wp_customize->add_setting('the_computer_repair_page_layout',array(
        'default' => __('One Column','the-computer-repair'),
        'sanitize_callback' => 'the_computer_repair_sanitize_choices'
	));
	$wp_customize->add_control('the_computer_repair_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','the-computer-repair'),
        'description' => __('Here you can change the sidebar layout for pages. ','the-computer-repair'),
        'section' => 'the_computer_repair_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','the-computer-repair'),
            'Right Sidebar' => __('Right Sidebar','the-computer-repair'),
            'One Column' => __('One Column','the-computer-repair')
        ),
	) );

	//Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'the_computer_repair_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ) );
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','the-computer-repair' ),
		'section' => 'the_computer_repair_left_right'
    )));

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'the_computer_repair_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ) );
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','the-computer-repair' ),
		'section' => 'the_computer_repair_left_right'
    )));

	//Pre-Loader
	$wp_customize->add_setting( 'the_computer_repair_loader_enable',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ) );
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','the-computer-repair' ),
        'section' => 'the_computer_repair_left_right'
    )));

	$wp_customize->add_setting('the_computer_repair_loader_icon',array(
        'default' => __('Two Way','the-computer-repair'),
        'sanitize_callback' => 'the_computer_repair_sanitize_choices'
	));
	$wp_customize->add_control('the_computer_repair_loader_icon',array(
        'type' => 'select',
        'label' => __('Pre-Loader Type','the-computer-repair'),
        'section' => 'the_computer_repair_left_right',
        'choices' => array(
            'Two Way' => __('Two Way','the-computer-repair'),
            'Dots' => __('Dots','the-computer-repair'),
            'Rotate' => __('Rotate','the-computer-repair')
        ),
	) );

	//Top Bar
	$wp_customize->add_section( 'the_computer_repair_topbar', array(
    	'title'      => __( 'Top Bar Settings', 'the-computer-repair' ),
		'panel' => 'the_computer_repair_panel_id'
	) );

	$wp_customize->add_setting( 'the_computer_repair_topbar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ));  
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_topbar_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Topbar','the-computer-repair' ),
          'section' => 'the_computer_repair_topbar'
    )));

    $wp_customize->add_setting('the_computer_repair_topbar_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_topbar_padding_top_bottom',array(
		'label'	=> __('Topbar Padding Top Bottom','the-computer-repair'),
		'description'	=> __('Enter a value in pixels. Example:20px','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_topbar',
		'type'=> 'text'
	));

    //Sticky Header
	$wp_customize->add_setting( 'the_computer_repair_sticky_header',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ) );
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','the-computer-repair' ),
        'section' => 'the_computer_repair_topbar'
    )));

	$wp_customize->add_setting( 'the_computer_repair_header_search',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ));  
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_header_search',array(
      	'label' => esc_html__( 'Show / Hide Search','the-computer-repair' ),
      	'section' => 'the_computer_repair_topbar'
    )));

    $wp_customize->add_setting('the_computer_repair_search_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_search_font_size',array(
		'label'	=> __('Search Font Size','the-computer-repair'),
		'description'	=> __('Enter a value in pixels. Example:20px','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('the_computer_repair_search_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_search_padding_top_bottom',array(
		'label'	=> __('Search Padding Top Bottom','the-computer-repair'),
		'description'	=> __('Enter a value in pixels. Example:20px','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('the_computer_repair_search_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_search_padding_left_right',array(
		'label'	=> __('Search Padding Left Right','the-computer-repair'),
		'description'	=> __('Enter a value in pixels. Example:20px','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'the_computer_repair_search_border_radius', array(
		'default'              => "",
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'the_computer_repair_search_border_radius', array(
		'label'       => esc_html__( 'Search Border Radius','the-computer-repair' ),
		'section'     => 'the_computer_repair_topbar',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'the_computer_repair_location', array( 
			'selector' => '.lower-bar p', 
			'render_callback' => 'the_computer_repair_customize_partial_the_computer_repair_location', 
	));

    $wp_customize->add_setting('the_computer_repair_location_icon',array(
		'default'	=> 'fas fa-map-marker-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new The_Computer_Repair_Fontawesome_Icon_Chooser(
        $wp_customize,'the_computer_repair_location_icon',array(
		'label'	=> __('Add Location Icon','the-computer-repair'),
		'transport' => 'refresh',
		'section'	=> 'the_computer_repair_topbar',
		'setting'	=> 'the_computer_repair_location_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('the_computer_repair_location',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_location',array(
		'label'	=> __('Add Location','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '123 Dummy street lorem ipsum, USA', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('the_computer_repair_phone_icon',array(
		'default'	=> 'fas fa-phone',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new The_Computer_Repair_Fontawesome_Icon_Chooser(
        $wp_customize,'the_computer_repair_phone_icon',array(
		'label'	=> __('Add Phone Icon','the-computer-repair'),
		'transport' => 'refresh',
		'section'	=> 'the_computer_repair_topbar',
		'setting'	=> 'the_computer_repair_phone_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('the_computer_repair_call',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_call',array(
		'label'	=> __('Add Phone Number','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '+00 1234 567 890', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('the_computer_repair_email_address_icon',array(
		'default'	=> 'fas fa-envelope',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new The_Computer_Repair_Fontawesome_Icon_Chooser(
        $wp_customize,'the_computer_repair_email_address_icon',array(
		'label'	=> __('Add Email Icon','the-computer-repair'),
		'transport' => 'refresh',
		'section'	=> 'the_computer_repair_topbar',
		'setting'	=> 'the_computer_repair_email_address_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('the_computer_repair_email',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_email',array(
		'label'	=> __('Add Email Address','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( 'example@gmail.com', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('the_computer_repair_top_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_top_btn_text',array(
		'label'	=> __('Add Button Text','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( 'FREE EVALUATION', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('the_computer_repair_top_btn_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('the_computer_repair_top_btn_url',array(
		'label'	=> __('Add Button URL','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( 'https://example.com/', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_topbar',
		'type'=> 'url'
	));

	$wp_customize->add_setting('the_computer_repair_cart_icon',array(
		'default'	=> 'fas fa-shopping-basket',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new The_Computer_Repair_Fontawesome_Icon_Chooser(
        $wp_customize,'the_computer_repair_cart_icon',array(
		'label'	=> __('Add Cart Icon','the-computer-repair'),
		'transport' => 'refresh',
		'section'	=> 'the_computer_repair_topbar',
		'setting'	=> 'the_computer_repair_cart_icon',
		'type'		=> 'icon'
	)));
    
	//Slider
	$wp_customize->add_section( 'the_computer_repair_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'the-computer-repair' ),
		'panel' => 'the_computer_repair_panel_id'
	) );

	$wp_customize->add_setting( 'the_computer_repair_slider_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ));  
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_slider_hide_show',array(
          'label' => esc_html__( 'Show / Hide Slider','the-computer-repair' ),
          'section' => 'the_computer_repair_slidersettings'
    )));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial(
    	'the_computer_repair_slider_hide_show',array(
			'selector'        => '#slider .inner_carousel h1',
			'render_callback' => 'the_computer_repair_customize_partial_the_computer_repair_slider_hide_show',
	));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'the_computer_repair_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'the_computer_repair_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'the_computer_repair_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'the-computer-repair' ),
			'description' => __('Slider image size (1600 x 600)','the-computer-repair'),
			'section'  => 'the_computer_repair_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('the_computer_repair_slider_content_option',array(
        'default' => __('Left','the-computer-repair'),
        'sanitize_callback' => 'the_computer_repair_sanitize_choices'
	));
	$wp_customize->add_control(new The_Computer_Repair_Image_Radio_Control($wp_customize, 'the_computer_repair_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','the-computer-repair'),
        'section' => 'the_computer_repair_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'the_computer_repair_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'the_computer_repair_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','the-computer-repair' ),
		'section'     => 'the_computer_repair_slidersettings',
		'type'        => 'range',
		'settings'    => 'the_computer_repair_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('the_computer_repair_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'the_computer_repair_sanitize_choices'
	));

	$wp_customize->add_control( 'the_computer_repair_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','the-computer-repair' ),
	'section'     => 'the_computer_repair_slidersettings',
	'type'        => 'select',
	'settings'    => 'the_computer_repair_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','the-computer-repair'),
      '0.1' =>  esc_attr('0.1','the-computer-repair'),
      '0.2' =>  esc_attr('0.2','the-computer-repair'),
      '0.3' =>  esc_attr('0.3','the-computer-repair'),
      '0.4' =>  esc_attr('0.4','the-computer-repair'),
      '0.5' =>  esc_attr('0.5','the-computer-repair'),
      '0.6' =>  esc_attr('0.6','the-computer-repair'),
      '0.7' =>  esc_attr('0.7','the-computer-repair'),
      '0.8' =>  esc_attr('0.8','the-computer-repair'),
      '0.9' =>  esc_attr('0.9','the-computer-repair')
	),
	));
 
	//Our Services section
	$wp_customize->add_section( 'the_computer_repair_services_section' , array(
    	'title'      => __( 'Our Services', 'the-computer-repair' ),
		'priority'   => null,
		'panel' => 'the_computer_repair_panel_id'
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'the_computer_repair_section_title', array( 
		'selector' => '.heading-box h2', 
		'render_callback' => 'the_computer_repair_customize_partial_the_computer_repair_section_title',
	));

	$wp_customize->add_setting('the_computer_repair_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_section_title',array(
		'label'	=> __('Add Section Title','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( 'Our Services', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_services_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('the_computer_repair_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_section_text',array(
		'label'	=> __('Add Section Text','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( 'lorem ipsum is dummy text', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_services_section',
		'type'=> 'text'
	));

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('the_computer_repair_our_services',array(
		'default'	=> 'select',
		'sanitize_callback' => 'the_computer_repair_sanitize_choices',
	));
	$wp_customize->add_control('the_computer_repair_our_services',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display Services','the-computer-repair'),
		'description' => __('Image Size (280 x 180)','the-computer-repair'),
		'section' => 'the_computer_repair_services_section',
	));

	//Blog Post
	$wp_customize->add_panel( $TheComputerRepairParentPanel );

	$BlogPostParentPanel = new The_Computer_Repair_WP_Customize_Panel( $wp_customize, 'blog_post_parent_panel', array(
		'title' => __( 'Blog Post Settings', 'the-computer-repair' ),
		'panel' => 'the_computer_repair_panel_id',
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'the_computer_repair_post_settings', array(
		'title' => __( 'Post Settings', 'the-computer-repair' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'the_computer_repair_toggle_postdate', array( 
			'selector' => '.post-main-box h2 a', 
			'render_callback' => 'the_computer_repair_customize_partial_the_computer_repair_toggle_postdate', 
	));

	$wp_customize->add_setting( 'the_computer_repair_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ) );
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','the-computer-repair' ),
        'section' => 'the_computer_repair_post_settings'
    )));

    $wp_customize->add_setting( 'the_computer_repair_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ) );
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_toggle_author',array(
		'label' => esc_html__( 'Author','the-computer-repair' ),
		'section' => 'the_computer_repair_post_settings'
    )));

    $wp_customize->add_setting( 'the_computer_repair_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ) );
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_toggle_comments',array(
		'label' => esc_html__( 'Comments','the-computer-repair' ),
		'section' => 'the_computer_repair_post_settings'
    )));

    $wp_customize->add_setting( 'the_computer_repair_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'the_computer_repair_switch_sanitization'
	));
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_toggle_tags', array(
		'label' => esc_html__( 'Tags','the-computer-repair' ),
		'section' => 'the_computer_repair_post_settings'
    )));

    $wp_customize->add_setting( 'the_computer_repair_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'the_computer_repair_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','the-computer-repair' ),
		'section'     => 'the_computer_repair_post_settings',
		'type'        => 'range',
		'settings'    => 'the_computer_repair_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog layout
    $wp_customize->add_setting('the_computer_repair_blog_layout_option',array(
        'default' => __('Default','the-computer-repair'),
        'sanitize_callback' => 'the_computer_repair_sanitize_choices'
    ));
    $wp_customize->add_control(new The_Computer_Repair_Image_Radio_Control($wp_customize, 'the_computer_repair_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','the-computer-repair'),
        'section' => 'the_computer_repair_post_settings',
        'choices' => array(
            'Default' => get_template_directory_uri().'/assets/images/blog-layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/blog-layout2.png',
            'Left' => get_template_directory_uri().'/assets/images/blog-layout3.png',
    ))));

    $wp_customize->add_setting('the_computer_repair_excerpt_settings',array(
        'default' => __('Excerpt','the-computer-repair'),
        'transport' => 'refresh',
        'sanitize_callback' => 'the_computer_repair_sanitize_choices'
	));
	$wp_customize->add_control('the_computer_repair_excerpt_settings',array(
        'type' => 'select',
        'label' => __('Post Content','the-computer-repair'),
        'section' => 'the_computer_repair_post_settings',
        'choices' => array(
        	'Content' => __('Content','the-computer-repair'),
            'Excerpt' => __('Excerpt','the-computer-repair'),
            'No Content' => __('No Content','the-computer-repair')
        ),
	) );

	$wp_customize->add_setting('the_computer_repair_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_post_settings',
		'type'=> 'text'
	));

    // Button Settings
	$wp_customize->add_section( 'the_computer_repair_button_settings', array(
		'title' => __( 'Button Settings', 'the-computer-repair' ),
		'panel' => 'blog_post_parent_panel',
	));

	$wp_customize->add_setting('the_computer_repair_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','the-computer-repair'),
		'description'	=> __('Enter a value in pixels. Example:20px','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('the_computer_repair_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','the-computer-repair'),
		'description'	=> __('Enter a value in pixels. Example:20px','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'the_computer_repair_button_border_radius', array(
		'default'              => '',
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'the_computer_repair_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','the-computer-repair' ),
		'section'     => 'the_computer_repair_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('the_computer_repair_button_text', array( 
			'selector' => '.post-main-box .more-btn a', 
			'render_callback' => 'the_computer_repair_customize_partial_the_computer_repair_button_text', 
	));

	$wp_customize->add_setting('the_computer_repair_button_text',array(
		'default'=> 'READ MORE',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_button_text',array(
		'label'	=> __('Add Button Text','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( 'READ MORE', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'the_computer_repair_related_posts_settings', array(
		'title' => __( 'Related Posts Settings', 'the-computer-repair' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('the_computer_repair_related_post_title', array( 
			'selector' => '.related-post h3', 
			'render_callback' => 'the_computer_repair_customize_partial_the_computer_repair_related_post_title', 
	));

    $wp_customize->add_setting( 'the_computer_repair_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ) );
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_related_post',array(
		'label' => esc_html__( 'Related Post','the-computer-repair' ),
		'section' => 'the_computer_repair_related_posts_settings'
    )));

    $wp_customize->add_setting('the_computer_repair_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_related_post_title',array(
		'label'	=> __('Add Related Post Title','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( 'Related Post', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('the_computer_repair_related_posts_count',array(
		'default'=> '3',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_related_posts_count',array(
		'label'	=> __('Add Related Post Count','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '3', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_related_posts_settings',
		'type'=> 'number'
	));

    //404 Page Setting
	$wp_customize->add_section('the_computer_repair_404_page',array(
		'title'	=> __('404 Page Settings','the-computer-repair'),
		'panel' => 'the_computer_repair_panel_id',
	));	

	$wp_customize->add_setting('the_computer_repair_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('the_computer_repair_404_page_title',array(
		'label'	=> __('Add Title','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('the_computer_repair_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('the_computer_repair_404_page_content',array(
		'label'	=> __('Add Text','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('the_computer_repair_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_404_page_button_text',array(
		'label'	=> __('Add Button Text','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( 'Go Back', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_404_page',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('the_computer_repair_responsive_media',array(
		'title'	=> __('Responsive Media','the-computer-repair'),
		'panel' => 'the_computer_repair_panel_id',
	));

	$wp_customize->add_setting( 'the_computer_repair_resp_topbar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ));  
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_resp_topbar_hide_show',array(
          'label' => esc_html__( 'Show / Hide Topbar','the-computer-repair' ),
          'section' => 'the_computer_repair_responsive_media'
    )));

    $wp_customize->add_setting( 'the_computer_repair_stickyheader_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ));  
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_stickyheader_hide_show',array(
          'label' => esc_html__( 'Sticky Header','the-computer-repair' ),
          'section' => 'the_computer_repair_responsive_media'
    )));

    $wp_customize->add_setting( 'the_computer_repair_resp_slider_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ));  
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_resp_slider_hide_show',array(
          'label' => esc_html__( 'Show / Hide Slider','the-computer-repair' ),
          'section' => 'the_computer_repair_responsive_media'
    )));

	$wp_customize->add_setting( 'the_computer_repair_metabox_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ));  
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_metabox_hide_show',array(
          'label' => esc_html__( 'Show / Hide Metabox','the-computer-repair' ),
          'section' => 'the_computer_repair_responsive_media'
    )));

    $wp_customize->add_setting( 'the_computer_repair_sidebar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ));  
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_sidebar_hide_show',array(
          'label' => esc_html__( 'Show / Hide Sidebar','the-computer-repair' ),
          'section' => 'the_computer_repair_responsive_media'
    )));

    $wp_customize->add_setting('the_computer_repair_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new The_Computer_Repair_Fontawesome_Icon_Chooser(
        $wp_customize,'the_computer_repair_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','the-computer-repair'),
		'transport' => 'refresh',
		'section'	=> 'the_computer_repair_responsive_media',
		'setting'	=> 'the_computer_repair_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('the_computer_repair_res_close_menu_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new The_Computer_Repair_Fontawesome_Icon_Chooser(
        $wp_customize,'the_computer_repair_res_close_menu_icon',array(
		'label'	=> __('Add Close Menu Icon','the-computer-repair'),
		'transport' => 'refresh',
		'section'	=> 'the_computer_repair_responsive_media',
		'setting'	=> 'the_computer_repair_res_close_menu_icon',
		'type'		=> 'icon'
	)));

	//Content Creation
	$wp_customize->add_section( 'the_computer_repair_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'the-computer-repair' ),
		'priority' => null,
		'panel' => 'the_computer_repair_panel_id'
	) );

	$wp_customize->add_setting('the_computer_repair_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new The_Computer_Repair_Content_Creation( $wp_customize, 'the_computer_repair_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','the-computer-repair' ),
		),
		'section' => 'the_computer_repair_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'the-computer-repair' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('the_computer_repair_footer',array(
		'title'	=> __('Footer Settings','the-computer-repair'),
		'panel' => 'the_computer_repair_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'the_computer_repair_footer_text', array( 
			'selector' => '#footer-2 .copyright p', 
		'render_callback' => 'the_computer_repair_customize_partial_the_computer_repair_footer_text', 
	));
	
	$wp_customize->add_setting('the_computer_repair_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('the_computer_repair_footer_text',array(
		'label'	=> __('Copyright Text','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2019, .....', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_footer',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('the_computer_repair_copyright_alingment',array(
        'default' => __('center','the-computer-repair'),
        'sanitize_callback' => 'the_computer_repair_sanitize_choices'
	));
	$wp_customize->add_control(new The_Computer_Repair_Image_Radio_Control($wp_customize, 'the_computer_repair_copyright_alingment', array(
        'type' => 'select',
        'label' => __('Copyright Alignment','the-computer-repair'),
        'section' => 'the_computer_repair_footer',
        'settings' => 'the_computer_repair_copyright_alingment',
        'choices' => array(
            'left' => get_template_directory_uri().'/assets/images/copyright1.png',
            'center' => get_template_directory_uri().'/assets/images/copyright2.png',
            'right' => get_template_directory_uri().'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting('the_computer_repair_copyright_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('the_computer_repair_copyright_padding_top_bottom',array(
		'label'	=> __('Copyright Padding Top Bottom','the-computer-repair'),
		'description'	=> __('Enter a value in pixels. Example:20px','the-computer-repair'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'the-computer-repair' ),
        ),
		'section'=> 'the_computer_repair_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'the_computer_repair_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'the_computer_repair_switch_sanitization'
    ));  
    $wp_customize->add_control( new The_Computer_Repair_Toggle_Switch_Custom_Control( $wp_customize, 'the_computer_repair_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','the-computer-repair' ),
      	'section' => 'the_computer_repair_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'the_computer_repair_scroll_to_top_icon', array( 
			'selector' => '.scrollup i', 
			'render_callback' => 'the_computer_repair_customize_partial_the_computer_repair_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('the_computer_repair_scroll_to_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new The_Computer_Repair_Fontawesome_Icon_Chooser(
        $wp_customize,'the_computer_repair_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','the-computer-repair'),
		'transport' => 'refresh',
		'section'	=> 'the_computer_repair_footer',
		'setting'	=> 'the_computer_repair_scroll_to_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('the_computer_repair_scroll_top_alignment',array(
        'default' => __('Right','the-computer-repair'),
        'sanitize_callback' => 'the_computer_repair_sanitize_choices'
	));
	$wp_customize->add_control(new The_Computer_Repair_Image_Radio_Control($wp_customize, 'the_computer_repair_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','the-computer-repair'),
        'section' => 'the_computer_repair_footer',
        'settings' => 'the_computer_repair_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));

    // Has to be at the top
	$wp_customize->register_panel_type( 'The_Computer_Repair_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'The_Computer_Repair_WP_Customize_Section' );
}

add_action( 'customize_register', 'the_computer_repair_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {

  class The_Computer_Repair_WP_Customize_Panel extends WP_Customize_Panel {

    public $panel;
    public $type = 'the_computer_repair_panel';
    public function json() {

      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
      $array['content'] = $this->get_content();
      $array['active'] = $this->active();
      $array['instanceNumber'] = $this->instance_number;
      return $array;
    }
  }
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  class The_Computer_Repair_WP_Customize_Section extends WP_Customize_Section {
  	
    public $section;
    public $type = 'the_computer_repair_section';
    public function json() {

      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
      $array['content'] = $this->get_content();
      $array['active'] = $this->active();
      $array['instanceNumber'] = $this->instance_number;

      if ( $this->panel ) {
        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
      } else {
        $array['customizeAction'] = 'Customizing';
      }
      return $array;
    }
  }
}

// Enqueue our scripts and styles
function the_computer_repair_customize_controls_scripts() {
  wp_enqueue_script( 'customizer-controls', get_theme_file_uri( '/assets/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'the_computer_repair_customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class The_Computer_Repair_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'The_Computer_Repair_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new The_Computer_Repair_Customize_Section_Pro( $manager,'example_1', array(
			'priority'   => 1,
			'title'    => esc_html__( 'Computer Repair Pro', 'the-computer-repair' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'the-computer-repair' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/computer-repair-wordpress-theme/'),
		)));

		$manager->add_section(new The_Computer_Repair_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Documentation', 'the-computer-repair' ),
			'pro_text' => esc_html__( 'DOCS', 'the-computer-repair' ),
			'pro_url'  => admin_url('themes.php?page=the_computer_repair_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'the-computer-repair-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'the-computer-repair-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
The_Computer_Repair_Customize::get_instance();